@@ -1,15 +1,16 @@
 package Pg::CLI::Role::Executable;
-{
-  $Pg::CLI::Role::Executable::VERSION = '0.11';
-}
-
-use Moose::Role;
 
+use strict;
+use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.12';
+
 use File::Which qw( which );
 use MooseX::Types::Moose qw( Str );
 
+use Moose::Role;
+
 has executable => (
     is      => 'ro',
     isa     => Str,
